Package 'imageTCGA'

Title: TCGA Diagnostic Image Database Explorer
Description: A Shiny application to explore the TCGA Diagnostic Image Database.
Authors: Ilaria Billato [aut, cre] (ORCID: <https://orcid.org/0000-0002-3335-3254>, affiliation: Department of Biology, University of Padova), Marcel Ramos [ctb] (affiliation: CUNY Graduate School of Public Health and Health Policy, New York, NY USA), Mohamed Omar [ctb] (affiliation: Department of Computational Biomedicine, Cedars-Sinai Medical Center, Los Angeles, California), Sehyun Oh [ctb] (affiliation: CUNY Graduate School of Public Health and Health Policy, New York, NY USA), Levi Waldron [ctb] (affiliation: CUNY Graduate School of Public Health and Health Policy, New York, NY USA), Davide Risso [ctb] (affiliation: Department of Statistical Sciences, University of Padova), Chiara Romualdi [ctb] (affiliation: Department of Biology, University of Padova)
Maintainer: Ilaria Billato <[email protected]>
License: Artistic-2.0
Version: 1.5.0
Built: 2026-05-30 07:57:57 UTC
Source: https://github.com/bioc/imageTCGA

Help Index


imageTCGA: A Shiny application to explore the TCGA Diagnostic Image Database

Description

This function launches a Shiny application that allows users to explore and download data from the TCGA Diagnostic Image Database.

Usage

imageTCGA()

Value

A Shiny application object

Examples

if (interactive()) {
    imageTCGA()
}